@@ -301,7 +301,8 @@ int
 ghttp_prepare(ghttp_request *a_request)
 {
   /* only allow http requests if no proxy has been set */
-  if (!a_request->proxy->host && strcmp(a_request->uri->proto, "http"))
+  if (!a_request->proxy->host && a_request->uri->proto &&
+      strcmp(a_request->uri->proto, "http"))
     return 1;
   /* check to see if we have to set up the
      host information */
@@ -668,6 +669,10 @@ ghttp_set_authinfo(ghttp_request *a_request,
   free(l_auth64);
   free(l_authtoken);
   /* copy the strings into the request */
+
+  if (a_request->username) free(a_request->username);
+  if (a_request->password) free(a_request->password);
+  if (a_request->authtoken) free(a_request->authtoken);
   a_request->username = strdup(a_user);
   a_request->password = strdup(a_pass);
   a_request->authtoken = l_final_auth;
@@ -733,6 +738,9 @@ ghttp_set_proxy_authinfo(ghttp_request *a_request,
   free(l_auth64);
   free(l_authtoken);
   /* copy the strings into the request */
+  if (a_request->proxy_username) free(a_request->proxy_username);
+  if (a_request->proxy_password) free(a_request->proxy_password);
+  if (a_request->proxy_authtoken) free(a_request->proxy_authtoken);
   a_request->proxy_username = strdup(a_user);
   a_request->proxy_password = strdup(a_pass);
   a_request->proxy_authtoken = l_final_auth;
