@@ -26,6 +26,8 @@
 
 typedef struct http_uri_tag
 {
+  char             *full;                          /* full URL */
+  char             *proto;                         /* protocol */
   char             *host;                          /* copy semantics */
   unsigned short    port;
   char             *resource;                      /* copy semantics */
